
/**********************************************************************************
 Persistence of Vision Ray Tracer Scene Description File
 File name   : Eval_pigmentTest.pov
 Version     : 3.7
 Description : Use of eval_pigment() to place objects in combination with trace()
               on a height_field or an isosurface
               with thanks to Norbert Kern's "Warm-up" (1st place IRTC May-June 2001)
               
 Date        : 2005/2016
 Author      : Thomas de Groot
 
 Copyright (C) 2005/2016. All rights reserved.
**********************************************************************************/

//+w640 +h640 +a0.3 +am2 +bm2

#version 3.7;

#include "colors.inc"
#include "functions.inc"
#include "rand.inc"
#include "transforms.inc"

global_settings {
  assumed_gamma 1.0
}

default {
  texture {
    pigment { rgb <1,0,0> }
  }
}

// ----------------------------------------
camera {
  location  <0.0, 50, -50.0>
  direction 1.5*z
  right     x*image_width/image_height
  angle     50
  look_at   <0.0, 0.0,  0.0>
}

sky_sphere {
  pigment {
    gradient y
    color_map {
      [0.0 rgb <0.6,0.7,1.0>]
      [0.7 rgb <0.0,0.1,0.8>]
    }
  }
}

light_source {
  <0, 0, 0>
  color rgb <1, 1, 1>
  translate <-30, 30, -30>
}

// ----------------------------------------
plane {
  y, -1
  pigment { color rgb <0.7,0.5,0.3> }
}

#declare SpottedMap = 
pigment {
  image_map {png "SpottedColor3x.png"} 
  rotate x*90 
  translate <-0.5,-0.5,-0.5> 
  scale <50, 1, 50>   //surface dimensions
} 

#declare HF =
height_field {
  png "plasma3.png" //or: 
  //png "SpottedColor3x.png" 
  translate <-0.5,-0.5,-0.5>
  scale <50, 2, 50>   //surface dimensions
  texture {
    pigment {Yellow}
  }
  finish {
    diffuse 0.7
  }
}

object {HF}

#declare Rod1 = cylinder { <0, 0, 0>, <0, 1, 0>, 0.05 texture {pigment {Red}}}
#declare Rod2 = cylinder { <0, 0, 0>, <0, 1, 0>, 0.05 texture {pigment {Green}}}
#declare Rod3 = cylinder { <0, 0, 0>, <0, 1, 0>, 0.05 texture {pigment {Blue}}}

#include "Eval_pigment.mcr"

// -------- Placing objects -------------
#declare Seed = seed(2);

#declare Spacing = 1;
#declare PosX = -40;

#while (PosX < 40)
  #declare PosZ = -40;
  #while (PosZ < 40)
    #declare Norm = <0, 0, 0>;
    #declare Start = <PosX+(rand(Seed)-0.5)*Spacing, 100, PosZ+(rand(Seed)-0.5)*Spacing>;
    #declare Pos = trace (HF, Start, -y, Norm );

    #if (Norm.x != 0 | Norm.y != 0 | Norm.z != 0)
        EvalPig3x(SpottedMap,Pos,Rod1,Rod2,Rod3,1,2,0,0,Seed)  // selection of objects according to eval_pigment of the image_map
    #end //end of if Norm

    #declare PosZ=PosZ+Spacing;
  #end //end of while Z

  #declare PosX=PosX+Spacing;
#end //end of while X

#debug "Done.\n\n"

